@@ -158,6 +158,7 @@ def deploy(_: Info, path: str, url: str, org: str, token: str):
 
     print("Deployed extension pack :tada:")
 
+
 @cli.command()
 @click.argument('id', required=True)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
@@ -172,6 +173,7 @@ def project(_: Info, id: str, token: str, url: str):
 
     KodexaPlatform.get_project(id)
 
+
 @cli.command()
 @click.argument('ref', required=True)
 @click.argument('path', required=True)
@@ -191,14 +193,13 @@ def upload(_: Info, ref: str, path: str, token: str, url: str):
 
 
 @cli.command()
-@click.argument('object_type', required=True)
-@click.argument('ref', required=False)
+@click.option('--org', help='The slug for the organization to deploy to', required=False)
 @click.option('--file', help='The path to the file containing the object to apply')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @click.option('--format', default=None, help='The format to input if from stdin (json, yaml)')
 @pass_info
-def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str, format=None):
-    """Apply an object to a Kodexa platform instance
+def apply(_: Info, org: Optional[str], file: str, token: str, format=None):
+    """Apply an object to a Kodexa platform instance from a file
     """
 
     KodexaPlatform.set_access_token(token)
@@ -206,7 +207,7 @@ def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str,
     obj = None
     if file is None:
         print("Reading from stdin")
-        if format == 'yaml':
+        if format == 'yaml' or format == 'yml':
             obj = yaml.safe_load(sys.stdin.read())
         elif format == 'json':
             obj = json.loads(sys.stdin.read())
@@ -217,14 +218,20 @@ def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str,
         with open(file, 'r') as f:
             if file.lower().endswith('.json'):
                 obj = json.load(f)
-            elif file.lower().endswith('.yaml'):
+            elif file.lower().endswith('.yaml') or file.lower().endswith('.yml'):
                 obj = yaml.safe_load(f)
             else:
                 raise Exception("Unsupported file type")
 
-    print("Applying object")
-    KodexaPlatform.apply(object_type, ref, obj)
-    print("Applied object :tada:")
+    if isinstance(obj, list):
+        print(f"Found {len(obj)} components")
+        for o in obj:
+            print("Applying component")
+            KodexaPlatform.apply(o, org)
+    else:
+        print("Applying component")
+        KodexaPlatform.apply(obj, org)
+    print("Applied component :tada:")
 
 
 @cli.command()
